DataBlockRef

Struct DataBlockRef 

pub struct DataBlockRef(/* private fields */);
CTA data block, defined in section 7.4.

Implementations

Source

impl DataBlockRef

pub fn tag(&self) -> DataBlockTag

Get the tag of the CTA data block.

pub fn sads(&self) -> impl Iterator<Item = Sad>

👎Deprecated since 0.3.0: use DataBlockRef::audio() instead

Get an array of short audio descriptors from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_AUDIO.

pub fn audio(&self) -> Option<AudioBlockRef>

Available on crate feature v0_3 only.

Get the audio from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_AUDIO.

pub fn speaker_alloc(&self) -> Option<SpeakerAllocBlock>

Get the speaker allocation from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_SPEAKER_ALLOC.

pub fn video_cap(&self) -> Option<VideoCapBlock>

Get the video capabilities from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO_CAP.

pub fn vesa_dddb(&self) -> Option<VesaDddb>

👎Deprecated since 0.3.0: use DataBlockRef::vesa_display_device() instead

Get the VESA Display Device Data Block (DDDB) from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VESA_DISPLAY_DEVICE.

pub fn vesa_display_device(&self) -> Option<VesaDisplayDeviceBlock>

Available on crate feature v0_3 only.

Get the VESA Display Device Data Block (DDDB) from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VESA_DISPLAY_DEVICE.

pub fn colorimetry(&self) -> Option<ColorimetryBlock>

Get the colorimetry data from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_COLORIMETRY.

pub fn hdr_static_metadata(&self) -> Option<HdrStaticMetadataBlock>

Get the HDR static metadata from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR_STATIC_METADATA.

pub fn hdr_dynamic_metadata(&self) -> Option<HdrDynamicMetadataBlock>

Get the HDR dynamic metadata from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR_DYNAMIC_METADATA.

pub fn svds(&self) -> impl Iterator<Item = Svd>

👎Deprecated since 0.3.0: use DataBlockRef::video() instead

Get an array of short video descriptors from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO.

pub fn video(&self) -> Option<VideoBlockRef>

Available on crate feature v0_3 only.

Get the video from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO.

pub fn ycbcr420_svds(&self) -> impl Iterator<Item = Svd>

👎Deprecated since 0.3.0: use DataBlockRef::ycbcr420_video() instead

Get an array of short video descriptors which only allow YCbCr 4:2:0 sampling mode from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420.

pub fn ycbcr420_video(&self) -> Option<Ycbcr420VideoBlockRef>

Available on crate feature v0_3 only.

Get the YCbCr video from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420.

pub fn vesa_transfer_characteristics( &self, ) -> Option<VesaTransferCharacteristics>

Get the Display Transfer Characteristic from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VESA_DISPLAY_TRANSFER_CHARACTERISTIC.

Upstream is not aware of any EDID blob containing a Display Transfer Characteristic data block. If such a blob is found, please share it with upstream!

pub fn ycbcr420_cap_map(&self) -> Option<Ycbcr420CapMapRef>

Get the YCbCr 4:2:0 Capability Map from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420_CAP_MAP.

pub fn infoframe(&self) -> Option<InfoframeBlockRef>

Get the InfoFrame information from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_INFOFRAME.

pub fn hdmi_audio(&self) -> Option<HdmiAudioBlockRef>

Available on crate features v0_2 or v0_3 only.

Get the HDMI Audio information from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDMI_AUDIO.

pub fn room_configuration(&self) -> Option<RoomConfiguration>

Available on crate features v0_2 or v0_3 only.

Get the Room Configuration from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_ROOM_CONFIG.

pub fn speaker_locations(&self) -> impl Iterator<Item = SpeakerLocations>

Available on crate features v0_2 or v0_3 only.

Get an array of Speaker Locations.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_SPEAKER_LOCATION.

pub fn did_type_vii_timing(&self) -> Option<TypeIIIVIITiming>

Available on crate features v0_2 or v0_3 only.

Get the DisplayID Type VII Video Timing from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_DISPLAYID_VIDEO_TIMING_VII.

pub fn svrs(&self) -> impl Iterator<Item = Svr>

👎Deprecated since 0.3.0: use DataBlockRef::video_format_pref() instead
Available on crate features v0_2 or v0_3 only.

Get an array of Short Video References (SVRs) from a CTA data block. The first SVR refers to the most-preferred Video Format, while the next SVRs are listed in order of decreasing preference.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO_FORMAT_PREF.

pub fn video_format_pref(&self) -> Option<VideoFormatPrefBlockRef>

Available on crate feature v0_3 only.

Get the Video Format Preference information from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO_FORMAT_PREF.

pub fn hdr10plus(&self) -> Option<HDR10PlusBlock>

Available on crate feature v0_3 only.

Get the HDR10+ information from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR10PLUS.

pub fn dolby_video(&self) -> Option<DolbyVideoBlock>

Available on crate feature v0_3 only.

Get the Dolby Vision information from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_DOLBY_VIDEO.

pub fn vendor_hdmi(&self) -> Option<VendorHdmiBlockRef>

Available on crate feature v0_3 only.

Get the vendor-specific HDMI information from a CTA data block.

Note, the HDMI and HDMI Forum vendor-specific data blocks are different.

Returns None if the data block tag is not\n DI_CTA_DATA_BLOCK_VENDOR_HDMI.

pub fn vendor_hdmi_forum(&self) -> Option<VendorHdmiForumBlock>

Available on crate feature v0_3 only.

Get the vendor-specific HDMI Forum information from a CTA data block.

Note, the HDMI and HDMI Forum vendor-specific data blocks are different.

Returns None if the data block tag is not\n DI_CTA_DATA_BLOCK_VENDOR_HDMI_FORUM.

pub fn hdmi_sink_cap(&self) -> Option<HdmiForumSinkCap>

Available on crate feature v0_3 only.

Get the HDMI Forum Sink Capability (HF-SCDB) from a CTA data block.

Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDMI_SINK_CAP.