VesaTransferCharacteristics

Struct VesaTransferCharacteristics 

pub struct VesaTransferCharacteristics {
    pub usage: VesaTransferCharacteristicsUsage,
    pub points_len: u8,
    pub points: [f32; 32],
}
👎Deprecated since 0.3.0: use VesaTransferCharacteristicsBlock instead
VESA Display Transfer Characteristic Data Block, defined in VESA Display Transfer Characteristics Data Block Standard Version 1.0

Contains 8, 16 or 32 evenly distributed points on the input axis describing the normalized relative luminance at that input. The first value includes the relative black level luminance.

Fields

usage: VesaTransferCharacteristicsUsage
👎Deprecated since 0.3.0: use VesaTransferCharacteristicsBlock instead
points_len: u8
👎Deprecated since 0.3.0: use VesaTransferCharacteristicsBlock instead
points: [f32; 32]
👎Deprecated since 0.3.0: use VesaTransferCharacteristicsBlock instead