pub struct VesaTransferCharacteristicsBlock {
pub usage: VesaTransferCharacteristicsUsage,
pub points_len: u8,
pub points: [f32; 32],
}Available on crate feature
v0_3 only.Expand description
VESA Display Transfer Characteristic Data Block, defined in VESA Display Transfer Characteristics Data Block Standard Version 1.0
Contains 8, 16 or 32 evenly distributed points on the input axis describing the normalized relative luminance at that input. The first value includes the relative black level luminance.
Fields
usage: VesaTransferCharacteristicsUsagepoints_len: u8points: [f32; 32]Trait Implementations
Sourceimpl Clone for VesaTransferCharacteristicsBlock
impl Clone for VesaTransferCharacteristicsBlock
Sourcefn clone(&self) -> VesaTransferCharacteristicsBlock
fn clone(&self) -> VesaTransferCharacteristicsBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<di_cta_vesa_transfer_characteristics_block> for VesaTransferCharacteristicsBlock
impl From<di_cta_vesa_transfer_characteristics_block> for VesaTransferCharacteristicsBlock
Sourcefn from(
value: di_cta_vesa_transfer_characteristics_block,
) -> VesaTransferCharacteristicsBlock
fn from( value: di_cta_vesa_transfer_characteristics_block, ) -> VesaTransferCharacteristicsBlock
Converts to this type from the input type.
impl Copy for VesaTransferCharacteristicsBlock