pub struct ColorManagementData {
pub version: i32,
pub red_a3: f32,
pub red_a2: f32,
pub green_a3: f32,
pub green_a2: f32,
pub blue_a3: f32,
pub blue_a2: f32,
}Expand description
EDID display Color Management Data, defined in section 3.10.3.7
Contains the coefficients for the function L = a₃ × v³ + a₂ × v²
describing the luminance response L to some voltage v [0, 0.7] for each color
channel.
For more information see VESA DCM Standard, Version 1; January 6, 2003
Fields
version: i32red_a3: f32red_a2: f32green_a3: f32green_a2: f32blue_a3: f32blue_a2: f32Trait Implementations
Sourceimpl Clone for ColorManagementData
impl Clone for ColorManagementData
Sourcefn clone(&self) -> ColorManagementData
fn clone(&self) -> ColorManagementData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColorManagementData
impl Debug for ColorManagementData
Sourceimpl From<di_edid_color_management_data> for ColorManagementData
impl From<di_edid_color_management_data> for ColorManagementData
Sourcefn from(value: di_edid_color_management_data) -> ColorManagementData
fn from(value: di_edid_color_management_data) -> ColorManagementData
Converts to this type from the input type.
impl Copy for ColorManagementData