DisplayDescriptorRef

Struct DisplayDescriptorRef 

pub struct DisplayDescriptorRef(/* private fields */);

Implementations

Source

impl DisplayDescriptorRef

pub fn tag(&self) -> DisplayDescriptorTag

Get the tag of an EDID display descriptor.

pub fn string(&self) -> Option<String>

Get the contents of a product serial number, a data string, or a product name display descriptor.

Returns None if the display descriptor tag isn’t either DI_EDID_DISPLAY_DESCRIPTOR_PRODUCT_SERIAL_NUMBER, DI_EDID_DISPLAY_DESCRIPTOR_DATA_STRING or DI_EDID_DISPLAY_DESCRIPTOR_PRODUCT_NAME.

pub fn range_limits(&self) -> Option<DisplayRangeLimits>

Get the contents of a display range limits descriptor.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_RANGE_LIMITS.

pub fn standard_timings(&self) -> Option<&[StandardTimingRef]>

Get a standard timing list from an EDID display descriptor.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_STD_TIMING_IDS.

pub fn color_points(&self) -> impl Iterator<Item = ColorPoint>

Get a color point list from an EDID display descriptor.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_COLOR_POINT.

Upstream is not aware of any EDID blob containing Color Point Descriptors. If such a blob is found, please share it with upstream!

pub fn established_timings_iii(&self) -> impl Iterator<Item = Timing>

Get a list of established timings III from an EDID display descriptor.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_ESTABLISHED_TIMINGS_III.

pub fn color_management_data(&self) -> Option<ColorManagementData>

Get the contents of a Display Color Management (DCM) Data descriptor.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_DCM_DATA.

Upstream is not aware of any EDID blob containing DCM Data descriptors. If such a blob is found, please share it with upstream!

pub fn cvt_timing_codes(&self) -> impl Iterator<Item = CvtTimingCode>

Get a list of CVT timing codes from an EDID display descriptor.

The highest priority code comes first, the lowest priority code last.

Returns None if the display descriptor tag isn’t DI_EDID_DISPLAY_DESCRIPTOR_CVT_TIMING_CODES.