Edid

Struct Edid 

pub struct Edid<'info> { /* private fields */ }
EDID data structure.

Implementations

Source

impl Edid<'_>

pub fn version(&self) -> i32

Get the EDID version.

pub fn revision(&self) -> i32

Get the EDID revision.

pub fn vendor_product(&self) -> VendorProduct

Get the EDID vendor product

pub fn video_input_analog(&self) -> Option<VideoInputAnalog>

Get the analog video input basic information.

Returns None if this isn’t an analog display.

pub fn video_input_digital(&self) -> Option<VideoInputDigital>

Get the digital video input basic information.

Returns None if this isn’t a digital display.

pub fn screen_size(&self) -> ScreenSize

Get the screen size.

pub fn basic_gamma(&self) -> Option<f32>

Get the display transfer characteristics from the basic EDID parameters, also known as "gamma".

Returns None if unset (ie, stored in an extension block).

pub fn dpms(&self) -> Dpms

Get the set of supported legacy DPMS states.

pub fn display_color_type(&self) -> DisplayColorType

Get the display color type.

For digital displays using EDID 1.4 and later, DisplayColorType::Undefined is always returned.

pub fn color_encoding_formats(&self) -> Option<ColorEncodingFormats>

Get the set of supported color encoding formats.

Returns None if the display is analog or if the color encoding formats are not specified.

pub fn misc_features(&self) -> MiscFeatures

Get the set of miscellaneous basic features.

pub fn chromaticity_coords(&self) -> ChromaticityCoords

Get chromaticity coordinates.

pub fn established_timings(&self) -> EstablishedTimings

Get established timings I and II.

pub fn standard_timings(&self) -> &[StandardTimingRef]

Get a list of EDID standard timings.

pub fn detailed_timing_defs(&self) -> impl Iterator<Item = DetailedTimingDef>

pub fn display_descriptors(&self) -> &[DisplayDescriptorRef]

Get a list of EDID display descriptors.

pub fn extensions(&self) -> &[ExtensionRef]

Get a list of EDID extensions.