MiscFeatures

Struct MiscFeatures 

pub struct MiscFeatures {
    pub has_preferred_timing: bool,
    pub default_gtf: bool,
    pub srgb_is_primary: bool,
    pub preferred_timing_is_native: bool,
    pub continuous_freq: bool,
}
Miscellaneous basic features, defined in section 3.6.4.

Note, the enum values don’t match the specification.

Fields

has_preferred_timing: bool

First detailed timing is the preferred timing.

Always set for EDID 1.4 and later.

default_gtf: bool

GTF using the default parameters is supported.

Never set for EDID 1.4 and later.

srgb_is_primary: bool

sRGB standard default color space is primary color space.

preferred_timing_is_native: bool

Preferred timing mode includes native pixel format and rate.

Never set for EDID 1.3 and earlier.

continuous_freq: bool

GTF or CVT generated timings within the display’s range limits are accepted.

Never set for EDID 1.3 and earlier.