pub struct DataBlockRef(/* private fields */);Expand description
CTA data block, defined in section 7.4.
Implementations
Sourceimpl DataBlockRef
impl DataBlockRef
Sourcepub fn tag(&self) -> DataBlockTag
pub fn tag(&self) -> DataBlockTag
Get the tag of the CTA data block.
Sourcepub fn sads(&self) -> impl Iterator<Item = Sad>
👎Deprecated since 0.3.0: use DataBlockRef::audio() instead
pub fn sads(&self) -> impl Iterator<Item = Sad>
DataBlockRef::audio() insteadGet an array of short audio descriptors from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_AUDIO.
Sourcepub fn audio(&self) -> Option<AudioBlockRef>
Available on crate feature v0_3 only.
pub fn audio(&self) -> Option<AudioBlockRef>
v0_3 only.Get the audio from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_AUDIO.
Sourcepub fn speaker_alloc(&self) -> Option<SpeakerAllocBlock>
pub fn speaker_alloc(&self) -> Option<SpeakerAllocBlock>
Get the speaker allocation from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_SPEAKER_ALLOC.
Sourcepub fn video_cap(&self) -> Option<VideoCapBlock>
pub fn video_cap(&self) -> Option<VideoCapBlock>
Get the video capabilities from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO_CAP.
Sourcepub fn vesa_dddb(&self) -> Option<VesaDddb>
👎Deprecated since 0.3.0: use DataBlockRef::vesa_display_device() instead
pub fn vesa_dddb(&self) -> Option<VesaDddb>
DataBlockRef::vesa_display_device() insteadGet the VESA Display Device Data Block (DDDB) from a CTA data block.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_VESA_DISPLAY_DEVICE.
Sourcepub fn vesa_display_device(&self) -> Option<VesaDisplayDeviceBlock>
Available on crate feature v0_3 only.
pub fn vesa_display_device(&self) -> Option<VesaDisplayDeviceBlock>
v0_3 only.Get the VESA Display Device Data Block (DDDB) from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VESA_DISPLAY_DEVICE.
Sourcepub fn colorimetry(&self) -> Option<ColorimetryBlock>
pub fn colorimetry(&self) -> Option<ColorimetryBlock>
Get the colorimetry data from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_COLORIMETRY.
Sourcepub fn hdr_static_metadata(&self) -> Option<HdrStaticMetadataBlock>
pub fn hdr_static_metadata(&self) -> Option<HdrStaticMetadataBlock>
Get the HDR static metadata from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR_STATIC_METADATA.
Sourcepub fn hdr_dynamic_metadata(&self) -> Option<HdrDynamicMetadataBlock>
pub fn hdr_dynamic_metadata(&self) -> Option<HdrDynamicMetadataBlock>
Get the HDR dynamic metadata from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR_DYNAMIC_METADATA.
Sourcepub fn svds(&self) -> impl Iterator<Item = Svd>
👎Deprecated since 0.3.0: use DataBlockRef::video() instead
pub fn svds(&self) -> impl Iterator<Item = Svd>
DataBlockRef::video() insteadGet an array of short video descriptors from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO.
Sourcepub fn video(&self) -> Option<VideoBlockRef>
Available on crate feature v0_3 only.
pub fn video(&self) -> Option<VideoBlockRef>
v0_3 only.Get the video from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_VIDEO.
Sourcepub fn ycbcr420_svds(&self) -> impl Iterator<Item = Svd>
👎Deprecated since 0.3.0: use DataBlockRef::ycbcr420_video() instead
pub fn ycbcr420_svds(&self) -> impl Iterator<Item = Svd>
DataBlockRef::ycbcr420_video() insteadGet an array of short video descriptors which only allow YCbCr 4:2:0 sampling mode from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420.
Sourcepub fn ycbcr420_video(&self) -> Option<Ycbcr420VideoBlockRef>
Available on crate feature v0_3 only.
pub fn ycbcr420_video(&self) -> Option<Ycbcr420VideoBlockRef>
v0_3 only.Get the YCbCr video from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420.
Sourcepub fn vesa_transfer_characteristics(
&self,
) -> Option<VesaTransferCharacteristics>
pub fn vesa_transfer_characteristics( &self, ) -> Option<VesaTransferCharacteristics>
Get the Display Transfer Characteristic from a CTA data block.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_VESA_DISPLAY_TRANSFER_CHARACTERISTIC.
Upstream is not aware of any EDID blob containing a Display Transfer Characteristic data block. If such a blob is found, please share it with upstream!
Sourcepub fn ycbcr420_cap_map(&self) -> Option<Ycbcr420CapMapRef>
pub fn ycbcr420_cap_map(&self) -> Option<Ycbcr420CapMapRef>
Get the YCbCr 4:2:0 Capability Map from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_YCBCR420_CAP_MAP.
Sourcepub fn infoframe(&self) -> Option<InfoframeBlockRef>
pub fn infoframe(&self) -> Option<InfoframeBlockRef>
Get the InfoFrame information from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_INFOFRAME.
Sourcepub fn hdmi_audio(&self) -> Option<HdmiAudioBlockRef>
Available on crate features v0_2 or v0_3 only.
pub fn hdmi_audio(&self) -> Option<HdmiAudioBlockRef>
v0_2 or v0_3 only.Get the HDMI Audio information from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDMI_AUDIO.
Sourcepub fn room_configuration(&self) -> Option<RoomConfiguration>
Available on crate features v0_2 or v0_3 only.
pub fn room_configuration(&self) -> Option<RoomConfiguration>
v0_2 or v0_3 only.Get the Room Configuration from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_ROOM_CONFIG.
Sourcepub fn speaker_locations(&self) -> impl Iterator<Item = SpeakerLocations>
Available on crate features v0_2 or v0_3 only.
pub fn speaker_locations(&self) -> impl Iterator<Item = SpeakerLocations>
v0_2 or v0_3 only.Get an array of Speaker Locations.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_SPEAKER_LOCATION.
Sourcepub fn did_type_vii_timing(&self) -> Option<TypeIIIVIITiming>
Available on crate features v0_2 or v0_3 only.
pub fn did_type_vii_timing(&self) -> Option<TypeIIIVIITiming>
v0_2 or v0_3 only.Get the DisplayID Type VII Video Timing from a CTA data block.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_DISPLAYID_VIDEO_TIMING_VII.
Sourcepub fn svrs(&self) -> impl Iterator<Item = Svr>
👎Deprecated since 0.3.0: use DataBlockRef::video_format_pref() insteadAvailable on crate features v0_2 or v0_3 only.
pub fn svrs(&self) -> impl Iterator<Item = Svr>
DataBlockRef::video_format_pref() insteadv0_2 or v0_3 only.Get an array of Short Video References (SVRs) from a CTA data block. The first SVR refers to the most-preferred Video Format, while the next SVRs are listed in order of decreasing preference.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_VIDEO_FORMAT_PREF.
Sourcepub fn video_format_pref(&self) -> Option<VideoFormatPrefBlockRef>
Available on crate feature v0_3 only.
pub fn video_format_pref(&self) -> Option<VideoFormatPrefBlockRef>
v0_3 only.Get the Video Format Preference information from a CTA data block.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_VIDEO_FORMAT_PREF.
Sourcepub fn hdr10plus(&self) -> Option<HDR10PlusBlock>
Available on crate feature v0_3 only.
pub fn hdr10plus(&self) -> Option<HDR10PlusBlock>
v0_3 only.Get the HDR10+ information from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_HDR10PLUS.
Sourcepub fn dolby_video(&self) -> Option<DolbyVideoBlock>
Available on crate feature v0_3 only.
pub fn dolby_video(&self) -> Option<DolbyVideoBlock>
v0_3 only.Get the Dolby Vision information from a CTA data block.
Returns None if the data block tag is not DI_CTA_DATA_BLOCK_DOLBY_VIDEO.
Sourcepub fn vendor_hdmi(&self) -> Option<VendorHdmiBlockRef>
Available on crate feature v0_3 only.
pub fn vendor_hdmi(&self) -> Option<VendorHdmiBlockRef>
v0_3 only.Get the vendor-specific HDMI information from a CTA data block.
Note, the HDMI and HDMI Forum vendor-specific data blocks are different.
Returns None if the data block tag is not\n DI_CTA_DATA_BLOCK_VENDOR_HDMI.
Sourcepub fn vendor_hdmi_forum(&self) -> Option<VendorHdmiForumBlock>
Available on crate feature v0_3 only.
pub fn vendor_hdmi_forum(&self) -> Option<VendorHdmiForumBlock>
v0_3 only.Get the vendor-specific HDMI Forum information from a CTA data block.
Note, the HDMI and HDMI Forum vendor-specific data blocks are different.
Returns None if the data block tag is not\n DI_CTA_DATA_BLOCK_VENDOR_HDMI_FORUM.
Sourcepub fn hdmi_sink_cap(&self) -> Option<HdmiForumSinkCap>
Available on crate feature v0_3 only.
pub fn hdmi_sink_cap(&self) -> Option<HdmiForumSinkCap>
v0_3 only.Get the HDMI Forum Sink Capability (HF-SCDB) from a CTA data block.
Returns None if the data block tag is not
DI_CTA_DATA_BLOCK_HDMI_SINK_CAP.