pub struct VendorHdmiBlock {Show 22 fields
pub source_phys_addr: u16,
pub supports_ai: bool,
pub supports_dc_48bit: bool,
pub supports_dc_36bit: bool,
pub supports_dc_30bit: bool,
pub supports_dc_y444: bool,
pub supports_dvi_dual: bool,
pub max_tmds_clock: c_int,
pub supports_content_graphics: bool,
pub supports_content_photo: bool,
pub supports_content_cinema: bool,
pub supports_content_game: bool,
pub has_latency: bool,
pub has_interlaced_latency: bool,
pub supports_progressive_video: bool,
pub supports_progressive_audio: bool,
pub supports_interlaced_video: bool,
pub supports_interlaced_audio: bool,
pub progressive_video_latency: c_int,
pub progressive_audio_latency: c_int,
pub interlaced_video_latency: c_int,
pub interlaced_audio_latency: c_int,
}Available on crate feature
v0_3 only.Expand description
HDMI vendor-specific data block.
This block is defined in HDMI 1.4b section 8.3.2.
Fields
source_phys_addr: u16supports_ai: boolsupports_dc_48bit: boolsupports_dc_36bit: boolsupports_dc_30bit: boolsupports_dc_y444: boolsupports_dvi_dual: boolmax_tmds_clock: c_intsupports_content_graphics: boolsupports_content_photo: boolsupports_content_cinema: boolsupports_content_game: boolhas_latency: boolIf !has_latency and !has_interlaced_latency, we have no latency information at all.
If only has_latency, video/audio latency fields are valid and should be used for both progressive and interlaced video/audio formats.
If both are valid, it means that video_latency and audio_latency should be used for progressive video/audio formats, and their interlaced counterpart for interlaced formats.
has_interlaced_latency: boolsupports_progressive_video: boolsupports_progressive_audio: boolsupports_interlaced_video: boolsupports_interlaced_audio: boolprogressive_video_latency: c_intprogressive_audio_latency: c_intinterlaced_video_latency: c_intinterlaced_audio_latency: c_intTrait Implementations
Sourceimpl Clone for VendorHdmiBlock
impl Clone for VendorHdmiBlock
Sourcefn clone(&self) -> VendorHdmiBlock
fn clone(&self) -> VendorHdmiBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VendorHdmiBlock
impl Debug for VendorHdmiBlock
Sourceimpl From<di_cta_vendor_hdmi_block> for VendorHdmiBlock
impl From<di_cta_vendor_hdmi_block> for VendorHdmiBlock
Sourcefn from(value: di_cta_vendor_hdmi_block) -> VendorHdmiBlock
fn from(value: di_cta_vendor_hdmi_block) -> VendorHdmiBlock
Converts to this type from the input type.
impl Copy for VendorHdmiBlock