pub struct MiscFeatures {
pub has_preferred_timing: bool,
pub default_gtf: bool,
pub srgb_is_primary: bool,
pub preferred_timing_is_native: bool,
pub continuous_freq: bool,
}Expand description
Miscellaneous basic features, defined in section 3.6.4.
Note, the enum values don’t match the specification.
Fields
has_preferred_timing: boolFirst detailed timing is the preferred timing.
Always set for EDID 1.4 and later.
default_gtf: boolGTF using the default parameters is supported.
Never set for EDID 1.4 and later.
srgb_is_primary: boolsRGB standard default color space is primary color space.
preferred_timing_is_native: boolPreferred timing mode includes native pixel format and rate.
Never set for EDID 1.3 and earlier.
continuous_freq: boolGTF or CVT generated timings within the display’s range limits are accepted.
Never set for EDID 1.3 and earlier.